@@ -622,11 +622,11 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
         }
         delete f;
         FXFREE(&data);
-        
+         
 		// Refresh the DirList and the FilePanel
-		setDirectory(targetdir,TRUE);
-		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(targetdir);
-		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+		//setDirectory(targetdir,TRUE);
+		//((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(targetdir);
+		//((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
 
 		return 1;
     }
