@@ -20,6 +20,7 @@ class FilePanel : public FXVerticalFrame
     FXDECLARE(FilePanel)
     friend class XFileExplorer;
     friend class DirPanel;
+    friend class DirList;
     friend class PathLinker;
 	friend class PropertiesBox;
 	friend class PreferencesBox;
@@ -35,6 +36,7 @@ protected:
 	FXbool			selmult;
 	FXString		homelocation;
 	FXString		trashlocation;
+	FXString		startlocation;
 	FXDragCorner    *corner;
 	FXDragType      urilistType;        // Standard uri-list type
 	FXDragType      xfelistType;        // Xfe, Gnome and XFCE list type
@@ -43,18 +45,20 @@ protected:
 	FXbool 			clipboard_locked;	// Clipboard locked to prevent changes when viewing it
 	InputDialog*    newfiledialog;
 	InputDialog*    newdirdialog;
+	InputDialog*    newlinkdialog;
 	HistInputDialog* opendialog;
 	ArchInputDialog* archdialog;
 	HistInputDialog* filterdialog;
-	BrowseInputDialog* operationdialog;
-	FXbool			 paste;
-
+	BrowseInputDialog* operationdialogsingle;
+	BrowseInputDialog* operationdialogmultiple;
+	FXbool			paste;
+	FXbool 			ctrlflag;			// Flag to select the right click control menu
+	FXbool			shiftf10;           // Flag indicating that Shift-F10 was pressed 
 public:
 
-
-
-FilePanel(FXchar*,FXComposite*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, FXuint ext_size=100, 
-	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXuint deldate_size=150, FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0),
+FilePanel(FXWindow *owner, const FXchar*,FXComposite*, FXuint name_size=200, FXuint size_size=60, FXuint type_size=100, FXuint ext_size=100, 
+	      FXuint modd_size=150, FXuint user_size=50, FXuint grou_size=50, FXuint attr_size=100, FXuint deldate_size=150,
+          FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXbool smoothscroll=TRUE,
  		  FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
     FilePanel()
     {}
@@ -74,20 +78,22 @@ FilePanel(FXchar*,FXComposite*, FXuint name_size=200, FXuint size_size=60, FXuin
         ID_FILE_COPY,
 		ID_FILE_CUT,
         ID_FILE_COPYTO,
-        ID_FILE_MOVE,
+        ID_FILE_MOVETO,
         ID_FILE_RENAME,
         ID_FILE_SYMLINK,
         ID_FILE_DELETE,
         ID_FILE_TRASH,
         ID_FILE_ASSOC,
-		ID_MENU,
+		ID_POPUP_MENU,
+		ID_CTRL_POPUP_MENU,
 		ID_XTERM,
         ID_EXTRACT,
 		ID_EXTRACT_TO_FOLDER,
         ID_EXTRACT_HERE,
         ID_NEW_DIR,
         ID_NEW_FILE,
-        ID_ADD_TO_ARCH,
+		ID_NEW_SYMLINK,
+		ID_ADD_TO_ARCH,
         ID_GO_HOME,
 		ID_GO_TRASH,
         ID_COPY_CLIPBOARD,
@@ -138,6 +144,7 @@ public:
     long onCmdFileAssoc(FXObject*,FXSelector,void*);
     long onCmdNewDir(FXObject*,FXSelector,void*);
     long onCmdNewFile(FXObject*,FXSelector,void*);
+	long onCmdNewSymlink(FXObject*,FXSelector,void*);
 	long onCmdOpen(FXObject*,FXSelector,void*);
     long onCmdOpenWith(FXObject*,FXSelector,void*);
 	long onCmdXTerm(FXObject*,FXSelector,void*);
@@ -147,6 +154,7 @@ public:
     long onCmdRefresh(FXObject*,FXSelector,void*);
     long onCmdSelect(FXObject*,FXSelector,void*);
     long onCmdPopupMenu(FXObject*,FXSelector,void*);
+	long onCmdCtrlPopupMenu(FXObject*,FXSelector,void*);
     long onCmdShow(FXObject*,FXSelector,void*);
     long onUpdShow(FXObject*,FXSelector,void*);
     long onUpdUp(FXObject*,FXSelector,void*);
