@@ -9,6 +9,7 @@
 class IconList;
 class FileList;
 
+
 // Icon item
 class FXAPI IconItem : public FXObject
 {
@@ -26,13 +27,12 @@ private:
     IconItem& operator=(const IconItem&);
 protected:
     IconItem():bigIcon(NULL),miniIcon(NULL),data(NULL),state(0){}
-    //virtual void draw(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
     virtual void draw(IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
     virtual FXint hitItem(const IconList* list,FXint rx,FXint ry,FXint rw=1,FXint rh=1) const;
 protected:
     virtual void drawBigIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
     virtual void drawMiniIcon(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-    //virtual void drawDetails(const IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+	FXbool isOdd(FXint i) const;
     virtual void drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
 public:
     enum
@@ -191,7 +191,7 @@ protected:
     FXint              cursor;            // Cursor item
     FXint              viewable;          // Visible item
     FXFont            *font;              // Font
-    IconListSortFunc sortfunc;            // Item sort function
+    IconListSortFunc   sortfunc;          // Item sort function
     FXColor            textColor;         // Text color
     FXColor            selbackColor;      // Selected back color
     FXColor            seltextColor;      // Selected text color
@@ -212,8 +212,12 @@ protected:
     FXbool             state;             // State of item
 	FXbool			   allowTooltip;      // Allow tooltip in single click mode
 	FXuint			   numsortheader;     // Index of the sorted column
+	FXdouble           headerpct[9];      // Header sizes, relatively to the list width (in percent)
+	FXint			   count;             // Counter used to properly initialize the relative header sizes
+
 protected:
-    IconList();
+    IconList()
+	{}
     void recompute();
     void getrowscols(FXint& nr,FXint& nc,FXint w,FXint h) const;
     void drawLasso(FXint x0,FXint y0,FXint x1,FXint y1);
@@ -226,6 +230,7 @@ private:
     IconList(const IconList&);
     IconList &operator=(const IconList&);
 public:
+	long onConfigure(FXObject*,FXSelector,void*);
     long onPaint(FXObject*,FXSelector,void*);
     long onEnter(FXObject*,FXSelector,void*);
     long onLeave(FXObject*,FXSelector,void*);
