@@ -1,6 +1,9 @@
 #ifndef OVERWRITEBOX_H
 #define OVERWRITEBOX_H
 
+
+#include "DialogBox.h"
+
 // Return values
 enum ConfirmOverWriteBoxReturn {
     MBOX_CLICKED_OVERWRITE    = 1,
@@ -11,7 +14,7 @@ enum ConfirmOverWriteBoxReturn {
 
 
 // Message box
-class FXAPI ConfirmOverWriteBox : public FXDialogBox
+class FXAPI ConfirmOverWriteBox : public DialogBox
 {
     FXDECLARE(ConfirmOverWriteBox)
 protected:
@@ -23,7 +26,7 @@ public:
     long onCmdClicked(FXObject*,FXSelector,void*);
 public:
     enum{
-        ID_CLICKED_OVERWRITE=FXDialogBox::ID_LAST,
+        ID_CLICKED_OVERWRITE=DialogBox::ID_LAST,
         ID_CLICKED_OVERWRITE_ALL,
         ID_CLICKED_SKIP,
         ID_CLICKED_SKIP_ALL,
